@@ -21,9 +21,9 @@ class QA4SMComparison:
     take some time, the class can be updated keeping memory of what has already been initialized
     """
     def __init__(self,
-                 paths: list or str,
+                 paths: Union[list, str],
                  extent: tuple = None,
-                 get_intersection: bool = True):
+                 get_intersection: bool = True) -> None:
         """
         Initialise the QA4SMImages from the paths to netCDF files specified
 
@@ -141,8 +141,8 @@ class QA4SMComparison:
             img_metrics = {}
             for metric in img.metrics:
                 # hardcoded because n_obs cannot be compared. todo: exclude empty metrics (problem: the values are not loaded here)
-                if metric in glob.metric_groups[0] or metric in [
-                        "tau", "p_tau"
+                if metric in glob.metric_groups['common'] or metric in [
+                        "tau", "p_tau", "status"
                 ]:
                     continue
                 img_metrics[metric] = glob._metric_name[metric]
@@ -333,12 +333,14 @@ class QA4SMComparison:
         ref_grid_stepsize = self.compared[0].ref_dataset_grid_stepsize
 
         ref = self._check_ref()["short_name"]
+        is_scattered = any([x.ds.attrs.get('val_is_scattered_data') == 'True' for x in self.compared])
         plm.plot_spatial_extent(polys=polys,
                                 ref_points=ref_points,
                                 overlapping=self.overlapping,
                                 intersection_extent=extent,
                                 reg_grid=(ref != "ISMN"),
-                                grid_stepsize=ref_grid_stepsize)
+                                grid_stepsize=ref_grid_stepsize,
+                                is_scattered=is_scattered)
 
     def _get_data(
         self, metric: str
@@ -593,6 +595,8 @@ class QA4SMComparison:
             glob.get_metric_units(ref_ds))
         figwidth = glob.boxplot_width * (len(df.columns) + 1)
         figsize = [figwidth, glob.boxplot_height]
+        df = df.reset_index().melt(id_vars = ["lat", "lon", "gpi"], var_name = "label", value_name="value").sort_values("label")
+        df["validation"] = [df["label"][i].split("Val")[1][:1] if len(df["label"][i].split("Val")) == 2 else f"{df["label"][i].split("Val")[1][:1]} - {df["label"][i].split("Val")[2][:1]}" for i in df.index]
         fig, axes = plm.boxplot(
             df,
             ci=ci,
@@ -603,9 +607,12 @@ class QA4SMComparison:
         fonts = {"fontsize": 12}
         title_plot = "Comparison of {} {}\nagainst the reference {}".format(
             Metric.pretty_name, um, self.ref["pretty_title"])
-        axes.set_title(title_plot, pad=glob.title_pad, **fonts)
+        axes[0].set_title(title_plot, pad=glob.title_pad, **fonts)
 
-        plm.make_watermark(fig, glob.watermark_pos, offset=0.04)
+        plm.add_logo_in_bg_front(fig, 
+                                 logo_path=glob.logo_pth,
+                                 position=glob.logo_position,
+                                 size=glob.logo_size)
         plt.tight_layout()
 
     def diff_mapplot(self, metric: str, **kwargs):
@@ -628,11 +635,14 @@ class QA4SMComparison:
         cbar_label = "Difference between {} and {}".format(
             *df.columns) + f"{um}"
 
+        # point data case
+        is_scattered = any([x.ds.attrs.get('val_is_scattered_data') == 'True' for x in self.compared])
         fig, axes = plm.mapplot(df.iloc[:, 2],
                                 metric=metric,
                                 ref_short=self.ref['short_name'],
                                 diff_map=True,
-                                label=cbar_label)
+                                label=cbar_label,
+                                is_scattered=is_scattered)
         fonts = {"fontsize": 12}
         title_plot = f"Overview of the difference in {Metric.pretty_name} " \
                      f"against the reference {self.ref['pretty_title']}"
@@ -640,6 +650,8 @@ class QA4SMComparison:
 
         plm.make_watermark(fig, glob.watermark_pos, offset=0.01)
 
+        return fig
+
     def wrapper(self, method: str, metric=None, **kwargs):
         """
         Call the method using a list of paths and the already initialised images
