@@ -6,8 +6,12 @@ Settings and global variables used in the reading and plotting procedures
 import warnings
 
 import cartopy.crs as ccrs
+import matplotlib
 import matplotlib.colors as cl
-import matplotlib.pyplot as plt
+import numpy as np
+import colorcet
+import seaborn as sns
+import os
 
 # PLOT DEFAULT SETTINGS
 # =====================================================
@@ -16,40 +20,142 @@ index_names = ['lat', 'lon',
                'gpi']  # Names used for 'latitude' and 'longitude' coordinate.
 time_name = 'time'  # not used at the moment, dropped on load
 period_name = 'period'  # not used at the moment, dropped on load
+no_print_period = ["bulk"] # List of period names which should not be printed in the title
 
 dpi_min = 100  # Resolution in which plots are going to be rendered.
 dpi_max = 200
-title_pad = 12.0  # Padding below the title in points. default padding is matplotlib.rcParams['axes.titlepad'] = 6.0
+title_pad = 12  # Padding below the title in points. default padding is matplotlib.rcParams['axes.titlepad'] = 6.0
 data_crs = ccrs.PlateCarree()  # Default map projection. use one of
+legend_alpha = 0.7
+ci_alpha = 0.4
+
+palette = sns.color_palette("Set2") #seaborn color palette used for dataset combination --> colors.py, colorblindfriendly options "Set2", "Dark2", "colorblind", ("Paired" not really useable in this case)
+exclude_from_palette = [6] # index of colors which you want removed from the set (depends on n_colors), for example 6 for "Set2" due to it just being not so nice to look at
+color_palette_combinations = [c for i, c in enumerate(palette) if i not in exclude_from_palette]
+color_palette_combinations_2 = sns.color_palette("Dark2") #if more combinations than len(color_palette_combinations)
+
+# === font defaults ===
+fontsize_title = 18
+fontsize_label = 16
+fontsize_ticklabel = 12
+fontsize_legend = 12
+
+# === Aggregate subplots defaults ===
+n_col_agg = 2
+max_subplots = 20
+
+# === axis defaults ===
+ax_left = 0.2
+ax_bottom = 0.15
+ax_width = 0.75
+ax_height = 0.8
 
 # === map plot defaults ===
 scattered_datasets = [
     'ISMN'
 ]  # dataset names which require scatterplots (values is scattered in lat/lon)
-map_figsize = [11.32, 6.10]  # size of the output figure in inches.
-naturalearth_resolution = '110m'  # One of '10m', '50m' and '110m'. Finer resolution slows down plotting. see https://www.naturalearthdata.com/
+map_figsize = [10, 7.5]  # size of the output figure in inches.
+map_ax_left = 0.1
+map_ax_bottom = 0.2
+map_ax_width = 0.8
+map_ax_height = 0.75
+
+cax_width =0.03
+
+resolution_th = [5, 30] # If one of the axis has an extent [°] below the thresholds change to finer resolution 
+naturalearth_resolution = ["10m",'50m','110m']  # One of '10m', '50m' and '110m'. Finer resolution slows down plotting. see https://www.naturalearthdata.com/
 crs = ccrs.PlateCarree(
 )  # projection. Must be a class from cartopy.crs. Note, that plotting labels does not work for most projections.
-markersize = 4  # diameter of Marker in points.
+min_markersize = 26 # min area of Marker in pixels
+max_markersize = 300 # max area of Marker in points
+nan_markersize = 16 # area of Marker for nan staions
 map_pad = 0.15  # padding relative to map height.
+min_gridlines = 4 # Minimum number of gridlines for each axis, if map too small no gridlines drawn
 grid_intervals = [
-    2, 5, 10, 30
+    0.1, 0.2, 0.5, 1, 2, 5, 10, 30
 ]  # grid spacing in degree to choose from (plotter will try to make 5 gridlines in the smaller dimension)
-max_title_len = 8 * map_figsize[
-    0]  # maximum length of plot title in chars. if longer, it will be broken in multiple lines.
+
+map_land_color = "#E7E2D6"
+map_water_color = "#e0f7fa"
 
 # === boxplot_basic defaults ===
-boxplot_printnumbers = True  # Print 'median', 'nObs', 'stdDev' to the boxplot_basic.
-boxplot_height = 6
+boxplot_height = 7 #$ increased by 1 to house logo
 boxplot_width = 2.1  # times (n+1), where n is the number of boxes.
-boxplot_title_len = 8 * boxplot_width  # times the number of boxes. maximum length of plot title in chars.
-tick_size = 8.5
 
+orient_th = 0 # If more number of bins > orient_th change to horizontal plot
+
+boxplot_height_horizontal = 7.5
+boxplot_width_horizontal = 12.5
+
+n_boxplots_in_row = 5
+
+bin_th = 2
+meta_bin_th = 15 # Above the threshold the figure height gets changes dynamically relative to # of bins
+no_growth_th_v = 1 # If equal or less bins than no_growth_th_v (vertical) the figure ylims get adjusted to not get gigantic boxes
+no_growth_th_h = 2 # If equal or less bins than no_growth_th_h (horizontal) the figure xlims get adjusted to not get gigantic boxes
+
+boxplot_height_vertical = 7.5
+boxplot_width_vertical = 5
+
+period_bin_th = 6 # Above the threshold the figure height gets changes dynamically relative to # of bins
+
+boxplot_edgecolor = "#000000" # color of the edgeline of the boxplot
+boxplot_edgewidth = 1 # width of edgeline of boxplot
+cap_factor = 2/3
+
+boxplot_new_coloring = True
+hatch_linewidth = 1.5
+num_hatches = 30
+boxplot_printnumbers = True  # Print 'median', 'nObs', 'stdDev' to the boxplot_basic.
+
+#TODO: remove eventually, as watermarlk string no longer needed
 # === watermark defaults ===
 watermark = u'made with QA4SM (qa4sm.eu)'  # Watermark string
 watermark_pos = 'bottom'  # Default position ('top' or 'bottom' or None)
 watermark_fontsize = 8  # fontsize in points (matplotlib uses 72ppi)
-watermark_pad = 5  # padding above/below watermark in points (matplotlib uses 72ppi)
+watermark_pad = 50  # padding above/below watermark in points (matplotlib uses 72ppi)
+
+#$$
+# === logo defaults ===
+rel_to_plot = ["front", "bg", "side"] # Possible positions relative to ax
+va_l = ["lower", "center", "upper"] # Possible vertical alignment
+ha_l = ["left", "center", "right"] # Possible horizontal alignment
+
+draw_logo = True
+logo_position = 'front_lower_right' # of format rel_to_plot[i]+"_"+va_l[j]+"_"+ha_l[k]
+n_col_logo = 1 # Number of columns forlogos
+n_logo = n_col_logo*1 # Number of logos to draw for position in ["bg", "in_front"]
+logo_alpha = 0.7
+logo_rotation = 0
+logo_pad = 0.01 # Percent of ax
+logo_size = 30  # height of the logo in pt
+logo_offset_comp_plots = (0, -0.1)
+logo_offset_metadata_plots = (0, -0.08)
+logo_offset_map_plots = (0, -0.15)
+logo_offset_bar_plots = (0, -0.1)
+logo_offset_box_plots = (0, -0.15)
+logo_pth = os.path.join(
+    os.path.dirname(
+        os.path.abspath(__file__)), 'static', 'images', 'logo',
+    'qa4sm_logo_long.webp')
+
+# Repositioning of legend if at same position as logo
+leg_loc_dict = {
+    "best": 0,
+    "upper right": 1,
+    "upper left": 2,
+    "lower left": 3,
+    "lower right": 4,
+    "right": 5,
+    "center left": 6,
+    "center right": 7,
+    "lower center": 8,
+    "upper center": 9,
+    "center center": 10,
+    "center": 10} # Dictionary mapping legend location to corresponding numbers
+
+pos_logo_lut = {f"{i}_{j}_{k}":leg_loc_dict[f"{j} {k}"] for i in rel_to_plot for j in va_l for k in ha_l}
+leg_loc_forbidden = [0, 5, 6, 7, 8, 9, 10, pos_logo_lut[logo_position]] # Positions where no legend placement is allowed
 
 # === filename template ===
 ds_fn_templ = "{i}-{ds}.{var}"
@@ -61,6 +167,7 @@ out_metadata_plots = {
     "climate": ["climate_KG"],
     "soil": ["instrument_depth", "soil_type"],
     "frm_class": ['frm_class'],
+    "network" : ['network'],
 }
 
 # === calculation errors (pytesmo) === #TODO: import from pytesmo
@@ -93,31 +200,54 @@ status_replace = {
 def get_status_colors():
     # function to get custom cmap for calculation errors
     # limited to 14 different error entries to produce distinct colors
-    cmap = plt.cm.get_cmap('Set3', len(status) - 2)
+    cmap = cl.ListedColormap(matplotlib.colormaps['Set3'].colors[:len(status) - 2])
     colors = [cmap(i) for i in range(cmap.N)]
     colors.insert(0, (0, 0.66666667, 0.89019608, 1.0))
     colors.insert(0, (0.45882353, 0.08235294, 0.11764706, 1.0))
     cmap = cl.ListedColormap(colors=colors)
     return cmap
 
-
-_cclasses = {
-    'div_better': plt.cm.get_cmap(
+# old cclasses
+_cclasses_old = {
+    'div_better': matplotlib.colormaps[
         'RdYlBu'
-    ),  # diverging: 1 good, 0 special, -1 bad (pearson's R, spearman's rho')
-    'div_worse': plt.cm.get_cmap(
+    ],  # diverging: 1 good, 0 special, -1 bad (pearson's R, spearman's rho')
+    'div_worse': matplotlib.colormaps[
         'RdYlBu_r'
-    ),  # diverging: 1 bad, 0 special, -1 good (difference of bias)
+    ],  # diverging: 1 bad, 0 special, -1 good (difference of bias)
     'div_neutr':
-    plt.cm.get_cmap('RdYlGn'),  # diverging: zero good, +/- neutral: (bias)
-    'seq_worse': plt.cm.get_cmap(
+    matplotlib.colormaps['RdYlGn'],  # diverging: zero good, +/- neutral: (bias)
+    'seq_worse': matplotlib.colormaps[
         'YlGn_r'
-    ),  # sequential: increasing value bad (p_R, p_rho, rmsd, ubRMSD, RSS)
-    'seq_better': plt.cm.get_cmap(
-        'YlGn'),  # sequential: increasing value good (n_obs, STDerr)
+    ],  # sequential: increasing value bad (p_R, p_rho, rmsd, ubRMSD, RSS)
+    'seq_better': matplotlib.colormaps[
+        'YlGn'],  # sequential: increasing value good (n_obs, STDerr)
+    'div_slopeBIAS': matplotlib.colormaps[
+        'RdBu_r'
+    ],  # diverging colormap for slopeBIAS
+    'div_slopeR': matplotlib.colormaps[
+        'PiYG'
+    ],  # diverging colormap for slopeR
+    'div_slopeURMSD': matplotlib.colormaps[
+        'PuOr'
+    ]  # diverging colormap for slopeURMSD
+}
+    
+# new cclasses
+_cclasses_new = {
+    'div_better': colorcet.m_CET_D1A_r,  # diverging: 1 good, 0 special, -1 bad (pearson's R, spearman's rho')
+    'div_worse': colorcet.m_CET_D1A,  # diverging: 1 bad, 0 special, -1 good (difference of bias)
+    'div_neutr':colorcet.m_CET_D13,  # diverging: zero good, +/- neutral: (bias)
+    'seq_worse': colorcet.m_CET_L18,  # sequential: increasing value bad (p_R, p_rho, rmsd, ubRMSD, RSS)
+    'seq_better': colorcet.m_blues,  # sequential: increasing value good (n_obs, STDerr)
     'qua_neutr':
     get_status_colors(),  # qualitative category with 2 forced colors
+    # Added colormaps for slope metrics
+    'div_slopeBIAS': colorcet.m_CET_D13,  # diverging colormap for slopeBIAS
+    'div_slopeR': colorcet.m_CET_D13,  # diverging colormap for slopeR
+    'div_slopeURMSD': colorcet.m_CET_D13  # diverging colormap for slopeURMSD
 }
+_cclasses = _cclasses_new
 
 _colormaps = {  # from /qa4sm/validator/validation/graphics.py
     'R': _cclasses['div_better'],
@@ -139,6 +269,9 @@ _colormaps = {  # from /qa4sm/validator/validation/graphics.py
     'err_std': _cclasses['seq_worse'],
     'beta': _cclasses['div_neutr'],
     'status': _cclasses['qua_neutr'],
+    'slopeR': _cclasses['div_slopeR'],
+    'slopeURMSD': _cclasses['div_slopeURMSD'],
+    'slopeBIAS': _cclasses['div_slopeBIAS'],
 }
 
 # Colorbars for difference plots
@@ -164,34 +297,42 @@ _diff_colormaps = {  # from /qa4sm/validator/validation/graphics.py
 
 # METRICS AND VARIABLES DEFINITIONS
 # =====================================================
-# 0=common metrics, 2=paired metrics (2 datasets), 3=triple metrics (TC, 3 datasets)
+# common metrics, pairwise metrics (2 datasets), triple metrics (TC, 3 datasets), pairwise stability metrics (2 datasets)
 metric_groups = {
-    0: ['n_obs'],
-    2: [
+    'common': ['n_obs'],
+    'pairwise': [
         'R', 'p_R', 'rho', 'p_rho', 'RMSD', 'BIAS', 'urmsd', 'mse', 'mse_corr',
-        'mse_bias', 'mse_var', 'RSS', 'tau', 'p_tau', 'status'
+        'mse_bias', 'mse_var', 'RSS', 'tau', 'p_tau', 'status' 
     ],
-    3: ['snr', 'err_std', 'beta', 'status']
+    'triple': ['snr', 'err_std', 'beta', 'status'],
+    'pairwise_stability': ['slopeURMSD', 'slopeR', 'slopeBIAS']
 }
 
+def get_metric_format(group, metric_dict):
+    # metric groups 'pairwise and 'pairwise_stability should be handled the same
+    if group == "pairwise_stability":
+        group = "pairwise"
+    return metric_dict.get(group)
+
 # === variable template ===
 # how the metric is separated from the rest
 var_name_metric_sep = {
-    0: "{metric}",
-    2: "{metric}_between_",
-    3: "{metric}_{mds_id:d}-{mds}_between_"
+    'common': "{metric}",
+    'pairwise': "{metric}_between_",
+    'triple': "{metric}_{mds_id:d}-{mds}_between_"
 }
+
 var_name_CI = {
-    0: "{metric}_ci_{bound}_between_",
-    2: "{metric}_ci_{bound}_between_",
-    3: "{metric}_ci_{bound}_{mds_id:d}-{mds}_between_"
+    'common': "{metric}_ci_{bound}_between_",
+    'pairwise': "{metric}_ci_{bound}_between_",
+    'triple': "{metric}_ci_{bound}_{mds_id:d}-{mds}_between_"
 }
 # how two datasets are separated, ids must be marked as numbers with :d!
 var_name_ds_sep = {
-    0: None,
-    2: "{ref_id:d}-{ref_ds}_and_{sat_id0:d}-{sat_ds0}",
-    3:
-    "{ref_id:d}-{ref_ds}_and_{sat_id0:d}-{sat_ds0}_and_{sat_id1:d}-{sat_ds1}"
+    'common': None,
+    'pairwise': "{ref_id:d}-{ref_ds}_and_{sat_id0:d}-{sat_ds0}",
+    'triple':
+    "{ref_id:d}-{ref_ds}_and_{sat_id0:d}-{sat_ds0}_and_{sat_id1:d}-{sat_ds1}",
 }
 
 # === metadata templates ===
@@ -202,17 +343,15 @@ _ds_pretty_name_attr = 'val_dc_dataset_pretty_name{:d}'  # attribute convention
 _version_short_name_attr = 'val_dc_version{:d}'  # attribute convention for other datasets
 _version_pretty_name_attr = 'val_dc_version_pretty_name{:d}'  # attribute convention for other datasets
 _val_dc_variable_pretty_name = 'val_dc_variable_pretty_name{:d}'  # attribute convention for variable name
+_val_dc_unit = 'val_dc_unit{:d}'
 
 # format should have (metric, ds, ref, other ds)
 _variable_pretty_name = {
-    0: "{}",
-    2: "{}\nof {}\nwith {} as reference",
-    3: "{} of {} \n against {}, {}"
+    'common': "{}",
+    'pairwise': "{}\nof {}\nwith {} as reference",
+    'triple': "{} of {} \n against {}, {}"
 }
 
-# check if every metric has a colormap
-for group in metric_groups.keys():
-    assert all([m in _colormaps.keys() for m in metric_groups[group]])
 
 # Value ranges of metrics, either absolute values, or a quantile between 0 and 1
 _metric_value_ranges = {  # from /qa4sm/validator/validation/graphics.py
@@ -232,9 +371,12 @@ _metric_value_ranges = {  # from /qa4sm/validator/validation/graphics.py
     'mse_bias': [0, None],
     'mse_var': [0, None],
     'snr': [None, None],
-    'err_std': [None, None],
+    'err_std': [0, None],
     'beta': [None, None],
     'status': [-1, len(status)-2],
+    'slopeR': [None, None],
+    'slopeURMSD': [None, None],
+    'slopeBIAS': [None, None],
 }
 # mask values out of range
 _metric_mask_range = {
@@ -266,9 +408,11 @@ _metric_description = {  # from /qa4sm/validator/validation/graphics.py
     'err_std': ' in {}',
     'beta': ' in {}',
     'status': '',
+    'slopeR': ' per decade',
+    'slopeURMSD': ' in {} per decade',
+    'slopeBIAS': ' in {} per decade',
 }
 
-
 # units for all datasets
 def get_metric_units(dataset, raise_error=False):
     # function to get m.u. with possibility to raise error
@@ -276,6 +420,9 @@ def get_metric_units(dataset, raise_error=False):
         'ISMN': 'm³/m³',
         'C3S': 'm³/m³',  # old name
         'C3S_combined': 'm³/m³',
+        'C3S_active': '% saturation',
+        'C3S_passive': 'm³/m³',
+        'C3S_rzsm': 'm³/m³',
         'GLDAS': 'm³/m³',
         'ASCAT': '% saturation',
         'SMAP': 'm³/m³',   # old name
@@ -285,6 +432,7 @@ def get_metric_units(dataset, raise_error=False):
         'ESA_CCI_SM_active': '% saturation',
         'ESA_CCI_SM_combined': 'm³/m³',
         'ESA_CCI_SM_passive': 'm³/m³',
+        'ESA_CCI_RZSM': 'm³/m³',
         'SMOS': 'm³/m³',   # old name
         'SMOS_IC': 'm³/m³',
         'CGLS_CSAR_SSM1km': '% saturation',
@@ -292,48 +440,132 @@ def get_metric_units(dataset, raise_error=False):
         'SMOS_L3': 'm³/m³',
         'SMOS_L2': 'm³/m³',
         'SMAP_L2': 'm³/m³',
+        'SMOS_SBPCA': 'm³/m³',
     }
 
-    try:
-        return _metric_units[dataset]
+    unit = _metric_units.get(dataset)
 
-    except KeyError:
+    if unit is None:
         if raise_error:
-            raise KeyError(
-                f"The dataset {dataset} has not been specified in {__name__}")
-
+            raise KeyError(f"The dataset '{dataset}' has not been specified in {__name__}.")
         else:
             warnings.warn(
-                f"The dataset {dataset} has not been specified in {__name__}. "
-                f"Set 'raise_error' to True to raise an exception for this case."
+                f"The dataset '{dataset}' has not been specified in {__name__}. "
+                "Set 'raise_error' to True to raise an exception for this case.",
+                UserWarning
             )
-
             return "n.a."
 
+    return unit
 
-# label name for all metrics
-_metric_name = {  # from /qa4sm/validator/validation/globals.py
+COMMON_METRICS = {
     'R': 'Pearson\'s r',
     'p_R': 'Pearson\'s r p-value',
-    'rho': 'Spearman\'s ρ',
-    'p_rho': 'Spearman\'s ρ p-value',
     'RMSD': 'Root-mean-square deviation',
-    'BIAS': 'Bias (difference of means)',
+    'BIAS': 'Bias',
     'n_obs': '# observations',
     'urmsd': 'Unbiased root-mean-square deviation',
     'RSS': 'Residual sum of squares',
-    'tau': 'Kendall rank correlation',
-    'p_tau': 'Kendall tau p-value',
     'mse': 'Mean square error',
     'mse_corr': 'Mean square error correlation',
     'mse_bias': 'Mean square error bias',
     'mse_var': 'Mean square error variance',
+}
+
+TC_METRICS = {
     'snr': 'Signal-to-noise ratio',
     'err_std': 'Error standard deviation',
     'beta': 'TC scaling coefficient',
-    'status': 'Validation errors'
 }
 
+READER_EXCLUSIVE_METRICS = {
+    'rho': 'Spearman\'s ρ',
+    'p_rho': 'Spearman\'s ρ p-value',
+    'tau': 'Kendall rank correlation',
+    'p_tau': 'Kendall tau p-value',
+    'status': 'Validation errors',
+}
+
+QA4SM_EXCLUSIVE_METRICS = {
+    'rho': 'Spearman\'s rho',
+    'p_rho': 'Spearman\'s rho p-value',
+    # 'tau': 'Kendall rank correlation',        # currently QA4SM is hardcoded not to calculate kendall tau
+    # 'p_tau': 'Kendall tau p-value',           # needs to be changed once tau is calculated again
+    'status': '# status',
+}
+
+STABILITY_METRICS = {
+    'slopeR' : 'Theil-Sen slope of R',
+    'slopeURMSD' : 'Theil-Sen slope of urmsd',
+    'slopeBIAS' : 'Theil-Sen slope of BIAS'
+}
+
+_metric_name = {**COMMON_METRICS, **READER_EXCLUSIVE_METRICS, **TC_METRICS, **STABILITY_METRICS}
+
+METRICS = {**COMMON_METRICS, **QA4SM_EXCLUSIVE_METRICS}
+
+ALL_METRICS = {**COMMON_METRICS, **READER_EXCLUSIVE_METRICS, **TC_METRICS, **STABILITY_METRICS}
+
+NON_METRICS = [
+    'gpi',
+    'lon',
+    'lat',
+    'clay_fraction',
+    'climate_KG',
+    'climate_insitu',
+    'elevation',
+    'instrument',
+    'latitude',
+    'lc_2000',
+    'lc_2005',
+    'lc_2010',
+    'lc_insitu',
+    'longitude',
+    'network',
+    'organic_carbon',
+    'sand_fraction',
+    'saturation',
+    'silt_fraction',
+    'station',
+    'timerange_from',
+    'timerange_to',
+    'variable',
+    'instrument_depthfrom',
+    'instrument_depthto',
+    'frm_class',
+]
+
+METADATA_TEMPLATE = {
+    'other_ref': None,
+    'ismn_ref': {
+        'clay_fraction': np.float32([np.nan]),
+        'climate_KG': np.array([' ' * 256]),
+        'climate_insitu': np.array([' ' * 256]),
+        'elevation': np.float32([np.nan]),
+        'instrument': np.array([' ' * 256]),
+        'latitude': np.float32([np.nan]),
+        'lc_2000': np.float32([np.nan]),
+        'lc_2005': np.float32([np.nan]),
+        'lc_2010': np.float32([np.nan]),
+        'lc_insitu': np.array([' ' * 256]),
+        'longitude': np.float32([np.nan]),
+        'network': np.array([' ' * 256]),
+        'organic_carbon': np.float32([np.nan]),
+        'sand_fraction': np.float32([np.nan]),
+        'saturation': np.float32([np.nan]),
+        'silt_fraction': np.float32([np.nan]),
+        'station': np.array([' ' * 256]),
+        'timerange_from': np.array([' ' * 256]),
+        'timerange_to': np.array([' ' * 256]),
+        'variable': np.array([' ' * 256]),
+        'instrument_depthfrom': np.float32([np.nan]),
+        'instrument_depthto': np.float32([np.nan]),
+        # only available for FRM4SM ISMN version(s)
+        'frm_class': np.array([' ' * 256]),
+    }
+}
+
+
 # BACKUPS
 # =====================================================
 # to fallback to in case the dataset attributes in the .nc file are
@@ -344,6 +576,9 @@ _metric_name = {  # from /qa4sm/validator/validation/globals.py
 _dataset_pretty_names = {  # from qa4sm\validator\fixtures\datasets.json
     'ISMN': 'ISMN',
     'C3S_combined': 'C3S SM combined',
+    'C3S_active': 'C3S SM active',
+    'C3S_passive': 'C3S SM passive',
+    'C3S_rzsm': 'C3S Root-zone SM',
     'C3S': 'C3S SM combined',  # old name for C3S_combined
     'GLDAS': 'GLDAS',
     'ASCAT': 'H-SAF ASCAT SSM CDR',
@@ -354,6 +589,7 @@ _dataset_pretty_names = {  # from qa4sm\validator\fixtures\datasets.json
     'ESA_CCI_SM_active': 'ESA CCI SM active',
     'ESA_CCI_SM_combined': 'ESA CCI SM combined',
     'ESA_CCI_SM_passive': 'ESA CCI SM passive',
+    'ESA_CCI_RZSM': 'ESA CCI Root-zone SM',
     'SMOS_IC': 'SMOS IC',
     'SMOS': 'SMOS IC',  # old name for SMOS IC
     'CGLS_CSAR_SSM1km': 'CGLS S1 SSM',
@@ -361,6 +597,7 @@ _dataset_pretty_names = {  # from qa4sm\validator\fixtures\datasets.json
     'SMOS_L3': 'SMOS L3',
     'SMOS_L2': 'SMOS L2',
     'SMAP_L2': 'SMAP L3',
+    'SMOS_SBPCA': 'SMOS SBPCA',
 }
 
 # available backups
@@ -404,6 +641,7 @@ _dataset_version_pretty_names = {  # from qa4sm\validator\fixtures\versions.json
     "SMOSL3_v339_DESC": "version 339 Descending",
     "SMAPL2_V8": 'V8',
     "SMOSL2_700": 'v700',
+    "SMOS_SBPCA_v724": "v724",
 }
 
 # fallback for dataset val_dc_variable in case they are not in the metadata
@@ -456,6 +694,9 @@ def get_resolution_info(dataset, raise_error=False):
     resolution = {  # from /qa4sm/validator/fixtures/datasets.json
         'ISMN': None,
         'C3S_combined': 0.25,
+        'C3S_active': 0.25,
+        'C3S_passive': 0.25,
+        'C3S_rzsm': 0.25,
         'C3S': 0.25,   # old name, unused
         'GLDAS': 0.25,
         'ASCAT': 12.5,
@@ -466,6 +707,7 @@ def get_resolution_info(dataset, raise_error=False):
         'ESA_CCI_SM_active': 0.25,
         'ESA_CCI_SM_combined': 0.25,
         'ESA_CCI_SM_passive': 0.25,
+        'ESA_CCI_RZSM': 0.25,
         'SMOS': 25,   # old name, unused
         'SMOS_IC': 25,
         'CGLS_CSAR_SSM1km': 1,
@@ -473,6 +715,7 @@ def get_resolution_info(dataset, raise_error=False):
         'SMOS_L3': 25,
         'SMOS_L2': 15,
         'SMAP_L2': 35,
+        'SMOS_SBPCA': 15,
     }
 
     # fallback for resolution unit information
@@ -480,6 +723,9 @@ def get_resolution_info(dataset, raise_error=False):
         'ISMN': 'point',
         'C3S': 'deg',  # old name, unused
         'C3S_combined': 'deg',
+        'C3S_active': 'deg',
+        'C3S_passive': 'deg',
+        'C3S_rzsm': 'deg',
         'GLDAS': 'deg',
         'ASCAT': 'km',
         'SMAP': 'km',   # old name, unused
@@ -489,6 +735,7 @@ def get_resolution_info(dataset, raise_error=False):
         'ESA_CCI_SM_active': 'deg',
         'ESA_CCI_SM_combined': 'deg',
         'ESA_CCI_SM_passive': 'deg',
+        'ESA_CCI_RZSM': 'deg',
         'SMOS': 'km',   # old name, unused
         'SMOS_IC': 'km',
         'CGLS_CSAR_SSM1km': 'km',
@@ -496,6 +743,7 @@ def get_resolution_info(dataset, raise_error=False):
         'SMOS_L3': 'km',
         'SMOS_L2': 'km',
         'SMAP_L2': 'km',
+        'SMOS_SBPCA': 'km',
     }
 
     try:
@@ -523,7 +771,7 @@ def get_resolution_info(dataset, raise_error=False):
 # information needed for plotting the metadata-boxplots
 
 # Min number of samples per bin to create a boxplot:
-meta_boxplot_min_samples = 5
+meta_boxplot_min_samples = 1
 
 lc_classes = {
     "unknown": "Not provided",
@@ -613,7 +861,7 @@ metadata = {
     "climate_insitu": ("climate in-situ", climate_classes, "classes", None),
     "elevation": ("elevation", None, "continuous", "[m]"),
     "instrument": ("instrument type", None, "discrete",
-                   None),  # todo: improve labels (too packed)
+                   None),  #todo: improve labels (too packed)
     "lc_2000": ("land cover class (2000)", lc_classes, "classes", None),
     "lc_2005": ("land cover class (2005)", lc_classes, "classes", None),
     "lc_2010": ("land cover class (2010)", lc_classes, "classes", None),
@@ -645,4 +893,109 @@ _metadata_exclude = [
     'tau',
     'p_tau',
     'status',
+    'slopeR',
+    'slopeURMSD',
+    'slopeBIAS',
 ]
+
+METRIC_TEMPLATE = '_between_{ds1}_and_{ds2}'
+METRIC_CI_TEMPLATE = '{metric}_ci_{bound}_between_{ds1}_and_{ds2}_{ending}'
+
+
+# intra-annual valdiation metric related settings
+# =====================================================
+
+DEFAULT_TSW = 'bulk' # default temporal sub-window (in the case of no temporal sub-windowing)
+TEMPORAL_SUB_WINDOW_NC_COORD_NAME = 'tsw' # name of the period coordinate in the netcdf file (Temporal Sub-Window)
+
+TEMPORAL_SUB_WINDOW_SEPARATOR = '|'
+
+INTRA_ANNUAL_METRIC_TEMPLATE = ["{tsw}", TEMPORAL_SUB_WINDOW_SEPARATOR,
+                                "{metric}"]  #$$
+
+INTRA_ANNUAL_TCOL_METRIC_TEMPLATE = ["{tsw}", TEMPORAL_SUB_WINDOW_SEPARATOR,
+                                "{metric}", "_", "{number}-{dataset}",
+                                "_between_"]
+
+# default temporal sub windows
+TEMPORAL_SUB_WINDOWS = {
+    "seasons": {
+        "S1": [[12, 1], [2, 28]],
+        "S2": [[3, 1], [5, 31]],
+        "S3": [[6, 1], [8, 31]],
+        "S4": [[9, 1], [11, 30]],
+    },
+    "months": {
+        "Jan": [[1, 1], [1, 31]],
+        "Feb": [[2, 1], [2, 28]],
+        "Mar": [[3, 1], [3, 31]],
+        "Apr": [[4, 1], [4, 30]],
+        'May': [[5, 1], [5, 31]],
+        "Jun": [[6, 1], [6, 30]],
+        "Jul": [[7, 1], [7, 31]],
+        "Aug": [[8, 1], [8, 31]],
+        "Sep": [[9, 1], [9, 30]],
+        "Oct": [[10, 1], [10, 31]],
+        "Nov": [[11, 1], [11, 30]],
+        "Dec": [[12, 1], [12, 31]],
+    },
+    #Fix as TemporalSubWindowsCreator checks pre-defined tsw on init
+    "stability":{
+    }
+}
+
+CLUSTERED_BOX_PLOT_STYLE = {
+    'fig_params': {
+        'title_fontsize': 20,
+        'y_labelsize': 18,
+        'tick_labelsize': 16,
+        'legend_fontsize': 12,
+    },
+    'colors': {
+        'Teal Blue':        '#00778F',
+        'Mustard Yellow':   '#FFD166',
+        'Sage Green':       '#8FB339',
+        'Coral Pink':       '#EF476F',
+        'Steel Gray':       '#6A0572',
+    }
+}
+
+CLUSTERED_BOX_PLOT_SAVENAME = 'comparison_boxplot_{metric}.{filetype}'
+
+CLUSTERED_BOX_PLOT_OUTDIR = 'comparison_boxplots'
+
+# netCDF transcription related settings
+# =====================================================
+OLD_NCFILE_SUFFIX = '.old'
+
+IMPLEMENTED_COMPRESSIONS = ['zlib']
+
+ALLOWED_COMPRESSION_LEVELS = [None, 0, 1, 2, 3, 4, 5, 6, 7, 8, 9]
+
+BAD_METRICS = ['time']
+
+DATASETS = [
+    'C3S_combined',
+    'C3S_active',
+    'C3S_passive',
+    'C3S_rzsm',
+    'ISMN',
+    'GLDAS',
+    'SMAP_L3',
+    'ASCAT',
+    'ESA_CCI_SM_combined',
+    'ESA_CCI_SM_active',
+    'ESA_CCI_SM_passive',
+    'ESA_CCI_RZSM',
+    'SMOS_IC',
+    'ERA5',
+    'ERA5_LAND',
+    'CGLS_CSAR_SSM1km',
+    'CGLS_SCATSAR_SWI1km',
+    'SMOS_L3',
+    'SMOS_L2',
+    'SMAP_L2',
+    'SMOS_SBPCA',
+]
+
+MAX_NUM_DS_PER_VAL_RUN = 6
