@@ -1,10 +1,14 @@
 # -*- coding: utf-8 -*-
-import warnings
-
+from dataclasses import dataclass
 from qa4sm_reader import globals
 from parse import *
-import warnings as warn
+import warnings
 import re
+import matplotlib
+import matplotlib.axes
+from matplotlib.figure import Figure
+from typing import List, Optional, Tuple, Dict, Any, Union
+
 
 
 class MixinVarmeta:
@@ -20,14 +24,14 @@ class MixinVarmeta:
             template = ""
         template = template + globals._variable_pretty_name[self.g]
 
-        if self.g == 0:
+        if self.g == 'common':
             name = template.format(self.metric)
 
-        elif self.g == 2:
+        elif self.g == 'pairwise' or self.g == 'pairwise_stability':
             name = template.format(self.Metric.pretty_name,
                                    self.metric_ds[1]['pretty_title'],
                                    self.ref_ds[1]['pretty_title'])
-        elif self.g == 3:
+        elif self.g == 'triple':
             name = template.format(self.Metric.pretty_name,
                                    self.metric_ds[1]['pretty_title'],
                                    self.ref_ds[1]['pretty_title'],
@@ -43,7 +47,7 @@ class MixinVarmeta:
         else:
             return self.ref_ds[0]
 
-    def get_varmeta(self) -> (tuple, tuple, tuple, tuple):
+    def get_varmeta(self) -> Tuple[Tuple, Tuple, Tuple, Tuple]:
         """
         Get the datasets from the current variable. Each dataset is provided with shape
         (id, dict{names})
@@ -56,12 +60,14 @@ class MixinVarmeta:
             this is the dataset for which the metric is calculated
         dss : id, dict
             this is the additional dataset in TC variables
+        sref_ds : id, dict
+            spatial reference dataset
         scale_ds: id, dict
             this is the scaling dataset
         """
-        if self.g == 0:
+        if self.g == 'common':
             ref_ds = self.Datasets.dataset_metadata(self.Datasets._ref_id())
-            mds, dss, scale_ds = None, None, None
+            mds, dss, scale_ds, sref_ds = None, None, None, self.Datasets.dataset_metadata(self.parts['sref_id'])
 
         else:
             scale_ds = None
@@ -76,17 +82,18 @@ class MixinVarmeta:
                     warnings.warn(
                         f"ID of scaling reference dataset could not be parsed, "
                         f"units of spatial reference are used.")
-
+        
             ref_ds = self.Datasets.dataset_metadata(self.parts['ref_id'])
+            sref_ds = self.Datasets.dataset_metadata(self.parts['sref_id'])
             mds = self.Datasets.dataset_metadata(self.parts['sat_id0'])
             dss = None
 
             # if metric is status and globals.metric_groups is 3, add third dataset
-            if self.g == 3 and self.metric == 'status':
+            if self.g == 'triple' and self.metric == 'status':
                 dss = self.Datasets.dataset_metadata(self.parts['sat_id1'])
 
             # if metric is TC, add third dataset
-            elif self.g == 3:
+            elif self.g == 'triple':
                 mds = self.Datasets.dataset_metadata(self.parts['mds_id'])
                 dss = self.Datasets.dataset_metadata(self.parts['sat_id1'])
                 if dss == mds:
@@ -97,7 +104,7 @@ class MixinVarmeta:
                     self.Datasets.dataset_metadata(self.parts['sat_id1'])
                 ]
 
-        return ref_ds, mds, dss, scale_ds
+        return ref_ds, mds, dss, scale_ds, sref_ds
 
 
 class QA4SMDatasets():
@@ -128,10 +135,20 @@ class QA4SMDatasets():
         ref_dc = 0
 
         try:
+            # print(f'globals._ref_ds_attr: {globals._ref_ds_attr}')
+            # print(f'self.meta: {self.meta}')
+            # print(
+            #     f'parse(globals._ds_short_name_attr, val_ref): {parse(globals._ds_short_name_attr, self.meta[globals._ref_ds_attr])}'
+            # )
+            # print(f'globals._ref_ds_attr: {globals._ref_ds_attr}')
+            # print(f'self.meta: {self.meta}')
+            # print(
+            #     f'parse(globals._ds_short_name_attr, val_ref): {parse(globals._ds_short_name_attr, self.meta[globals._ref_ds_attr])}'
+            # )
             val_ref = self.meta[globals._ref_ds_attr]
             ref_dc = parse(globals._ds_short_name_attr, val_ref)[0]
         except KeyError as e:
-            warn("The netCDF file does not contain the attribute {}".format(
+            warnings.warn("The netCDF file does not contain the attribute {}".format(
                 globals._ref_ds_attr))
             raise e
 
@@ -245,8 +262,9 @@ class QA4SMDatasets():
         }
 
         # not from dataset.
-        names['mu'] = "{}".format(globals.get_metric_units(
-            names['short_name']))
+        names['mu'] = self._fetch_attribute("_val_dc_unit", dc)
+        if names["mu"] == "":
+            names["mu"] = "{}".format(globals.get_metric_units(names['short_name']))
 
         # combined name for plots:
         names['pretty_title'] = '{} ({})'.format(names['pretty_name'],
@@ -298,7 +316,7 @@ class QA4SMDatasets():
 
         return others_meta
 
-    def dataset_metadata(self, id: int, element: str or list = None) -> tuple:
+    def dataset_metadata(self, id: int, element: Union[str, list] = None) -> tuple:
         """
         Get the metadata for the dataset specified by the id. This function is used by the QA4SMMetricVariable class
 
@@ -395,27 +413,31 @@ class QA4SMVariable():
     @property
     def ismetric(self) -> bool:
         return self.g is not None
+    
+    def numbers_at_end_int(self, s):
+        match = re.search(r'(\d+)$', s)
+        return int(match.group(1))
 
     def _parse_wrap(self, pattern, g):
         """Wrapper function that handles case of metric 'status' that occurs
-        in two globals.metric_groups (2,3). This is because a status array
+        in two globals.metric_groups (pairwise,triple). This is because a status array
         can be the result of a validation between two or three datasets (tc)
         """
-        # ignore this case - (status is also in globals.metric_groups 2 but
-        # should be treated as group 3)
+        # ignore this case - (status is also in pairwise metric_groups but
+        # should be treated as triple metric_group)
         if self.varname.startswith('status') and (self.varname.count('_and_')
-                                                  == 2) and g == 2:
+                                                  == 2) and g == 'pairwise':
             return None
         # parse self.varname when three datasets
         elif self.varname.startswith('status') and (self.varname.count('_and_')
-                                                    == 2) and g == 3:
-            template = globals.var_name_ds_sep[3]
+                                                    == 2) and g == 'triple':
+            template = globals.var_name_ds_sep['triple']
             return parse(
-                '{}{}'.format(globals.var_name_metric_sep[2], template),
+                '{}{}'.format(globals.var_name_metric_sep['pairwise'], template),
                 self.varname)
         return parse(pattern, self.varname)
 
-    def _parse_varname(self) -> (str, int, dict):
+    def _parse_varname(self) -> Tuple[str, str, dict]:
         """
         Parse the name to get the metric, group and variable data
 
@@ -423,7 +445,7 @@ class QA4SMVariable():
         -------
         metric : str
             metric name
-        g : int
+        g : str
             group
         parts : dict
             dictionary of MetricVariable data
@@ -431,24 +453,27 @@ class QA4SMVariable():
         metr_groups = list(globals.metric_groups.keys())
         # check which group it belongs to
         for g in metr_groups:
-            template = globals.var_name_ds_sep[g]
+            template = globals.get_metric_format(g, globals.var_name_ds_sep)
             if template is None:
                 template = ''
-            pattern = '{}{}'.format(globals.var_name_metric_sep[g], template)
+            pattern = '{}{}'.format(globals.get_metric_format(g, globals.var_name_metric_sep), template)
             # parse infromation from pattern and name
 
             parts = self._parse_wrap(pattern, g)
-
-            if parts is not None and parts['metric'] in globals.metric_groups[
-                    g]:
-                return parts['metric'], g, parts.named
+            if parts is not None and parts['metric'] in globals.metric_groups[g]:
+                parts_dict = parts.named
+                parts_dict['sref_id'] = self.numbers_at_end_int(self.attrs["val_ref"]) # spatial reference always 0
+                parts_dict['sref_ds'] = self.attrs[self.attrs["val_ref"]]
+                return parts['metric'], g, parts_dict
             # perhaps it's a CI variable
             else:
-                pattern = '{}{}'.format(globals.var_name_CI[g], template)
+                pattern = '{}{}'.format(globals.get_metric_format(g, globals.var_name_CI), template)
                 parts = parse(pattern, self.varname)
-                if parts is not None and parts[
-                        'metric'] in globals.metric_groups[g]:
-                    return parts['metric'], g, parts.named
+                if parts is not None and parts['metric'] in globals.metric_groups[g]:
+                    parts_dict = parts.named
+                    parts_dict['sref_id'] = self.numbers_at_end_int(self.attrs["val_ref"]) # spatial reference always 0
+                    parts_dict['sref_ds'] = self.attrs[self.attrs["val_ref"]]
+                    return parts['metric'], g, parts_dict
 
         return None, None, None
 
@@ -460,7 +485,7 @@ class MetricVariable(QA4SMVariable, MixinVarmeta):
         super().__init__(varname, global_attrs, values)
 
         self.Metric = QA4SMMetric(self.metric)
-        self.ref_ds, self.metric_ds, self.other_ds, _ = self.get_varmeta()
+        self.ref_ds, self.metric_ds, self.other_ds, self.scl_ref, self.sref_ds = self.get_varmeta()
 
 
 class ConfidenceInterval(QA4SMVariable, MixinVarmeta):
@@ -470,7 +495,7 @@ class ConfidenceInterval(QA4SMVariable, MixinVarmeta):
         super().__init__(varname, global_attrs, values)
 
         self.Metric = QA4SMMetric(self.metric)
-        self.ref_ds, self.metric_ds, self.other_ds, _ = self.get_varmeta()
+        self.ref_ds, self.metric_ds, self.other_ds, _, self.sref_ds = self.get_varmeta()
 
         self.bound = self.parts["bound"]
 
@@ -524,7 +549,7 @@ class QA4SMMetric():
         """
         for n, Var in enumerate(self.variables):
             value = getattr(Var, attr)
-            # special case for "status" attribute (self.g can be 2 or 3)
+            # special case for "status" attribute (self.g can be 'pairwise' or 'triple')
             if n != 0 and not Var.varname.startswith('status'):
                 assert value == previous, "The attribute {} is not equal in all variables".format(
                     attr)
@@ -542,3 +567,24 @@ class QA4SMMetric():
                 break
 
         return it_does
+
+#$$
+@dataclass()
+class ClusteredBoxPlotContainer:
+    '''Container for the figure and axes of a clustered boxplot.
+    See `qa4sm_reader.plotting_methods.figure_template` for usage.
+    '''
+    fig: matplotlib.figure.Figure
+    ax_box: matplotlib.axes.Axes
+    ax_median: Optional[matplotlib.axes.Axes] = None
+    ax_iqr: Optional[matplotlib.axes.Axes] = None
+    ax_n: Optional[matplotlib.axes.Axes] = None
+
+#$$
+@dataclass(frozen=True)
+class CWContainer:
+    '''Container for the centers and widths of the boxplots. Used for the plotting of the clustered boxplots.'''
+    centers: List[float]
+    widths: List[float]
+    name: Optional[str] = 'Generic Dataset'
+
