@@ -2,25 +2,13 @@
 from qa4sm_reader import globals
 import qa4sm_reader.handlers as hdl
 from qa4sm_reader.plotting_methods import _format_floats, combine_soils, combine_depths, average_non_additive
-
+from qa4sm_reader.utils import transcribe
 from pathlib import Path
 import warnings
 
-import numpy as np
 import xarray as xr
 import pandas as pd
-from typing import Union
-
-
-def extract_periods(filepath) -> np.array:
-    """Get periods from .nc"""
-    dataset = xr.open_dataset(filepath)
-    if globals.period_name in dataset.dims:
-        return dataset[globals.period_name].values
-
-    else:
-        return np.array([None])
-
+from typing import Union, Tuple, Optional
 
 class SpatialExtentError(Exception):
     """Class to handle errors derived from the spatial extent of validations"""
@@ -31,7 +19,7 @@ class QA4SMImg(object):
     """A tool to analyze the results of a validation, which are stored in a netCDF file."""
     def __init__(self,
                  filepath,
-                 period=None,
+                 period=globals.DEFAULT_TSW,
                  extent=None,
                  ignore_empty=True,
                  metrics=None,
@@ -46,8 +34,8 @@ class QA4SMImg(object):
         ----------
         filepath : str
             Path to the results netcdf file (as created by QA4SM)
-        period : Any, optional (default: None)
-            If results for multiple validation periods are stored in file,
+        period : str, optional (default: `globals.DEFAULT_TSW`)
+            if results for multiple validation periods, i.e. multiple temporal sub-windows, are stored in file,
             load this period.
         extent : tuple, optional (default: None)
             Area to subset the values for -> (min_lon, max_lon, min_lat, max_lat)
@@ -84,17 +72,36 @@ class QA4SMImg(object):
             except AttributeError:
                 self.ref_dataset_grid_stepsize = 'nan'
 
-    def _open_ds(self, extent=None, period=None, engine='h5netcdf'):
-        """Open .nc as xarray datset, with selected extent"""
+    def _open_ds(self, extent: Optional[Tuple]=None, period:Optional[str]=globals.DEFAULT_TSW, engine:Optional[str]='h5netcdf') -> xr.Dataset:
+        """Open .nc as `xarray.Datset`, with selected extent and period.
+
+        Parameters
+        ----------
+        extent : tuple, optional (default: None)
+            Area to subset the values for -> (min_lon, max_lon, min_lat, max_lat)
+        period : str, optional (default: `globals.DEFAULT_TSW`)
+            if results for multiple validation periods, i.e. multiple temporal sub-windows, are stored in file,
+            load this period.
+        engine: str, optional (default: h5netcdf)
+            Engine used by xarray to read data from file.
+
+        Returns
+        -------
+        ds : xarray.Dataset
+            Dataset with the validation results
+        """
         dataset = xr.load_dataset(
             self.filepath,
             drop_variables="time",
             engine=engine,
         )
-        if period is not None:
-            ds = dataset.sel(dict(period=period))
-        else:
-            ds = dataset
+
+        if not globals.TEMPORAL_SUB_WINDOW_NC_COORD_NAME in dataset.dims:
+            dataset = transcribe(self.filepath)
+
+
+        selection = {globals.TEMPORAL_SUB_WINDOW_NC_COORD_NAME: period}  # allows for flexible loading of both the dimension and temproal sub-window
+        ds = dataset.sel(selection)
         # drop non-spatial variables (e.g.'time')
         if globals.time_name in ds.variables:
             ds = ds.drop_vars(globals.time_name)
@@ -326,7 +333,7 @@ class QA4SMImg(object):
 
         return vars
 
-    def group_metrics(self, metrics: list = None) -> (dict, dict, dict):
+    def group_metrics(self, metrics: list = None) -> Union[None, Tuple[dict, dict, dict]]:
         """
         Load and group all metrics from file
 
@@ -344,11 +351,11 @@ class QA4SMImg(object):
         # fill dictionaries
         for metric in metrics:
             Metric = self.metrics[metric]
-            if Metric.g == 0:
+            if Metric.g == 'common':
                 common[metric] = Metric
-            elif Metric.g == 2:
+            elif Metric.g == 'pairwise' or Metric.g == 'pairwise_stability':
                 double[metric] = Metric
-            elif Metric.g == 3:
+            elif Metric.g == 'triple':
                 triple[metric] = Metric
 
         return common, double, triple
@@ -394,7 +401,7 @@ class QA4SMImg(object):
 
         return df
 
-    def metric_df(self, metrics: str or list):
+    def metric_df(self, metrics: Union[str, list]) -> pd.DataFrame:
         """
         Group all variables for the metric in a common data frame
 
@@ -431,6 +438,8 @@ class QA4SMImg(object):
                                       "metric": Var.metric,
                                       "metric_ds": Var.metric_ds,
                                       "other_ds": Var.other_ds,
+                                      "ref_ds": Var.ref_ds,
+                                      "sref_ds": Var.sref_ds,
                                   }):
             values = ci.values
             values.columns = [ci.bound]
@@ -444,7 +453,7 @@ class QA4SMImg(object):
         where the dataset with id=id is the metric dataset.
 
         Parameters
-        ----------
+        ----------        return cis
         metric : str
             A metric that is in the file (e.g. n_obs, R, ...)
         id: int
@@ -483,17 +492,17 @@ class QA4SMImg(object):
 
             # find the statistics for the metric variable
             var_stats = [mean, values.median(), iqr]
-            if Var.g == 0:
+            if Var.g == 'common':
                 var_stats.append('All datasets')
                 var_stats.extend([globals._metric_name[metric], Var.g])
 
             else:
                 i, ds_name = Var.metric_ds
-                if Var.g == 2:
+                if Var.g == 'pairwise' or Var.g == 'pairwise_stability':
                     var_stats.append('{}-{} ({})'.format(
                         i, ds_name['short_name'], ds_name['pretty_version']))
 
-                elif Var.g == 3:
+                elif Var.g == 'triple':
                     o, other_ds = Var.other_ds
                     var_stats.append(
                         '{}-{} ({}); other ref: {}-{} ({})'.format(
@@ -501,12 +510,10 @@ class QA4SMImg(object):
                             ds_name['pretty_version'], o,
                             other_ds['short_name'],
                             other_ds['pretty_version']))
-                unit_ref = self.datasets.ref['short_name']
-                _, _, _, scl_meta = Var.get_varmeta()
+                _, _, _, scl_meta, _ = Var.get_varmeta()
+                um = globals._metric_description[metric].format(self.datasets.ref['mu'])
                 if scl_meta:
-                    unit_ref = scl_meta[1]['short_name']
-                um = globals._metric_description[metric].format(
-                    globals.get_metric_units(unit_ref))
+                    um = globals._metric_description[metric].format(scl_meta[1]['mu'])
                 metric_def = f"{globals._metric_name[metric]} {um}"
 
                 var_stats.extend([metric_def, Var.g])
