@@ -39,7 +39,7 @@ def double_img_paths():
 
 @pytest.fixture
 def double_img_overlap(double_img_paths):
-    """Initialized souble image comparison with intersection"""
+    """Initialized double image comparison with intersection"""
     return QA4SMComparison(double_img_paths)
 
 
@@ -95,19 +95,24 @@ def test_wrapper(single_img, double_img_overlap):
     This tests the wrapper function but more in general also the
     plotting functions/table
     """
-    methods = ['boxplot', 'mapplot']
-    for method in methods:
-        out = single_img.wrapper(method, "R")
-        plt.close("all")
-        assert not out  # generates a plot and returns nothing
+    # Define expected return types for each method
+    method_expectations = {
+        'boxplot': None,  # returns None
+        'mapplot': plt.Figure  # returns matplotlib Figure
+    }
+
+    # Test both image objects
+    for img in [single_img, double_img_overlap]:
+        for method, expected_type in method_expectations.items():
+            out = img.wrapper(method, "R")
+            plt.close("all")
+
+            if expected_type is None:
+                assert not out
+            else:
+                assert isinstance(out, expected_type)
+
 
-    for method in methods:
-        out = double_img_overlap.wrapper(method, "R")
-        plt.close("all")
-        if method == "table":
-            assert out is not None  # generates a pandas dataframe
-        else:
-            assert not out  # generates a plot and returns nothing
 
 
 def test_init_union(double_img_overlap):
@@ -172,7 +177,7 @@ def test_common_metrics(double_img_paths, double_img_overlap):
         # 'tau': 'Kendall rank correlation',
         'mse_bias': 'Mean square error bias',
         'p_rho': "Spearman's ρ p-value",
-        'BIAS': 'Bias (difference of means)',
+        'BIAS': 'Bias',
         'urmsd': 'Unbiased root-mean-square deviation',
         'mse_var': 'Mean square error variance'
     }
@@ -202,7 +207,7 @@ def test_get_data(double_img_overlap):
     data, ci = double_img_overlap._get_data("R").values()
     assert len(data) == 2
     data = data[0]
-    name_should = 'Val0: 1-C3S (v202012) '
+    name_should = 'Val0: 0 & 1 '
     assert data.name == name_should
     data_should = [
         0.679918, 0.707091, 0.713081, 0.808353, 0.700307, 0.852756, 0.714132,
