@@ -14,6 +14,7 @@ from qa4sm_reader.plotting_methods import geotraj_to_geo2d, _dict2df, bin_contin
     bin_discrete, combine_soils, combine_depths, output_dpi, average_non_additive
 from qa4sm_reader.handlers import Metadata
 from qa4sm_reader.globals import dpi_min, dpi_max, get_resolution_info
+import qa4sm_reader.globals as globals
 
 
 @pytest.fixture
@@ -390,7 +391,7 @@ def test_scaling_reference_unit(ref_scaling_ds_plotter, plotdir):
     img = ref_scaling_ds_plotter.img
     g = img._iter_vars(filter_parms={'metric': 'RMSD'})
     Var = next(g)
-    ref_meta, mds_meta, other_meta, scl_meta = Var.get_varmeta()
+    ref_meta, mds_meta, other_meta, scl_meta, sref_meta = Var.get_varmeta()
     mds_unit = mds_meta[1]['mu']
     ref_unit = ref_meta[1]['mu']
     scl_unit = scl_meta[1]['mu']
@@ -430,7 +431,8 @@ def test_bin_continuous():
 
     assert binned.keys() == exp.keys()
     for act, expected in zip(binned.values(), exp.values()):
-        pd.testing.assert_series_equal(act[act.columns[0]], expected)
+        pd.testing.assert_series_equal(act[act.columns[0]], expected,
+                                       check_index_type=False)
 
 
 def test_bin_classes():
@@ -458,7 +460,8 @@ def test_bin_discrete():
     exp["instrument"] = data
     exp["Dataset"] = "dataset"
 
-    pd.testing.assert_frame_equal(binned, exp)
+    pd.testing.assert_frame_equal(binned, exp,
+                                  check_index_type=False)
 
 
 def test_combine_soils():
@@ -477,7 +480,8 @@ def test_combine_soils():
     exp = pd.DataFrame(data=["Coarse\ngran.", "Fine\ngran.", "Coarse\ngran."],
                        columns=["soil_type"])
 
-    pd.testing.assert_frame_equal(combined, exp)
+    pd.testing.assert_frame_equal(combined, exp,
+                                  check_index_type=False)
 
 
 def test_combine_depths():
@@ -496,7 +500,8 @@ def test_combine_depths():
                        data=np.full(10, 0.5),
                        columns=["instrument_depth"])
 
-    pd.testing.assert_frame_equal(combined, exp)
+    pd.testing.assert_frame_equal(combined, exp,
+                                  check_index_type=False)
 
 
 def test_dict2df():
@@ -597,3 +602,7 @@ def test_average_non_additive():
     # Included in the standard interval
     assert 0.5 < avg < 0.7
     assert avg != np.mean(values)
+
+
+def test_logo_exists():
+    assert os.path.exists(os.path.join(os.path.dirname(__file__), '..', 'src', 'qa4sm_reader', 'static', 'images', 'logo', 'QA4SM_logo_long.png'))
